==> web-7.0.0.tgz: package/lib/combo/DropItem.js <==
import * as React from "react";
import { SvgIcon } from "../my-icon/index";
var activeStatus;
(function (activeStatus) {
    activeStatus["select"] = "selected";
    activeStatus["hasSelect"] = "hasSelect";
    activeStatus["noSelect"] = "noSelect";
})(activeStatus || (activeStatus = {}));
class DropItem extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.checkFn = (e) => {
            const dom = e.currentTarget;
            const value = dom.value;
            this.props.checkMethod(value);
        };
        this.clickFn = (e) => {
            const dom = e.currentTarget;
            const index = dom.dataset.index;
            this.props.clickFn(index);
        };
    }
    getCheckbox(text, icon) {
        const { node, index, CheckBox } = this.props;
        const active = node.get("active");
        const hasChecked = activeStatus.hasSelect === active;
        const checked = activeStatus.select === active;
        return CheckBox ? (React.createElement(CheckBox, { hasChecked: hasChecked, checked: checked, value: index, changeHandle: this.checkFn },
            icon,
            React.createElement("span", { className: "combo-text" }, text))) : (React.createElement(React.Fragment, null,
            icon,
            React.createElement("span", { className: "combo-text" }, text)));
    }
    render() {
        const { node, index, lev, fieldObj, formatterDropItem } = this.props;
        const levSpaceStyle = lev !== undefined ? { paddingLeft: `${lev}em` } : undefined;
        const icon = fieldObj.get("itemIcon");
        const text = formatterDropItem
            ? formatterDropItem(node)
            : node.get(fieldObj.get("textField"));
        const multiply = fieldObj.get("multiply");
        const iconCom = icon ? React.createElement(SvgIcon, { className: icon }) : undefined;
        const fn = levSpaceStyle && multiply ? undefined : this.clickFn;
        const activeName = levSpaceStyle && multiply
            ? ""
            : node.get("active") === activeStatus.select
                ? "active"
                : "";
        return (React.createElement("li", null,
            React.createElement("div", { className: `m-combo-item ${activeName}`, "data-index": index, onClick: fn },
                React.createElement("span", { className: "g-item-text", style: levSpaceStyle }, this.getCheckbox(text, iconCom)))));
    }
}
export { DropItem, activeStatus };

==> web-9.0.0.tgz: package/lib/combo/DropItem.js <==
import * as React from "react";
import { SvgIcon } from "../my-icon/index";
var activeStatus;
(function (activeStatus) {
    activeStatus["select"] = "selected";
    activeStatus["hasSelect"] = "hasSelect";
    activeStatus["noSelect"] = "noSelect";
})(activeStatus || (activeStatus = {}));
class DropItem extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.checkFn = (e) => {
            const dom = e.currentTarget;
            const value = dom.value;
            this.props.checkMethod(value);
        };
        this.clickFn = (e) => {
            const dom = e.currentTarget;
            const index = dom.dataset.index;
            this.props.clickFn(index);
        };
    }
    getCheckbox(text, icon) {
        const { node, index, CheckBox } = this.props;
        const active = node.get("active");
        const hasChecked = activeStatus.hasSelect === active;
        const checked = activeStatus.select === active;
        return CheckBox ? (React.createElement(CheckBox, { hasChecked: hasChecked, checked: checked, type: "checkbox", value: index, changeHandle: this.checkFn },
            icon,
            React.createElement("span", { className: "combo-text" }, text))) : (React.createElement(React.Fragment, null,
            icon,
            React.createElement("span", { className: "combo-text" }, text)));
    }
    render() {
        const { node, index, lev, fieldObj, formatterDropItem } = this.props;
        const levSpaceStyle = lev !== undefined ? { paddingLeft: `${lev}em` } : undefined;
        const icon = fieldObj.get("itemIcon");
        const text = formatterDropItem
            ? formatterDropItem(node)
            : node.get(fieldObj.get("textField"));
        const multiply = fieldObj.get("multiply");
        const iconCom = icon ? React.createElement(SvgIcon, { className: icon }) : undefined;
        const fn = levSpaceStyle && multiply ? undefined : this.clickFn;
        const activeName = levSpaceStyle && multiply
            ? ""
            : node.get("active") === activeStatus.select
                ? "active"
                : "";
        return (React.createElement("li", null,
            React.createElement("div", { className: `m-combo-item ${activeName}`, "data-index": index, onClick: fn },
                React.createElement("span", { className: "g-item-text", style: levSpaceStyle }, this.getCheckbox(text, iconCom)))));
    }
}
export { DropItem, activeStatus };
